@@ -55,32 +55,32 @@ MASTSize <- function(tree1, tree2 = tree1, rooted = TRUE) {
 #' @importFrom ape drop.tip
 #' @importFrom TreeTools Postorder RenumberTips TreeIsRooted RootOnNode
 .MASTSizeSingle <- function(tree1, tree2, rooted = TRUE,
-                             tipLabels = tree1$tip.label,
+                             tipLabels = tree1[["tip.label"]],
                              ...) {
   label1 <- tipLabels
-  label2 <- tree2$tip.label
+  label2 <- tree2[["tip.label"]]
   
   tree1 <- drop.tip(tree1, setdiff(label1, label2))
-  label1 <- tree1$tip.label
+  label1 <- tree1[["tip.label"]]
   tree2 <- RenumberTips(drop.tip(tree2, setdiff(label2, label1)), label1)
   
   nTip <- length(label1)
   
   if (!rooted) {
     if (!TreeIsRooted(tree1)) {
-      tree1 <- RootOnNode(tree1, node = tree1$edge[nTip + nTip - 2L], TRUE)
+      tree1 <- RootOnNode(tree1, node = tree1[["edge"]][nTip + nTip - 2L], TRUE)
     }
-    postorderEdge1 <- Postorder(tree1$edge)
+    postorderEdge1 <- Postorder(tree1[["edge"]])
     tree2 <- Preorder(tree2)
-    max(vapply(tree2$edge[, 2], function(node)
+    max(vapply(tree2[["edge"]][, 2], function(node)
       .MASTSizeEdges(postorderEdge1,
-                     RootOnNode(tree2, node = node, TRUE)$edge,
+                     RootOnNode(tree2, node = node, TRUE)[["edge"]],
                      nTip = nTip), 0L))
   } else {
     if (!TreeIsRooted(tree1) || !TreeIsRooted(tree2)) {
       stop("Both trees must be rooted if rooted = TRUE")
     }
-    .MASTSizeEdges(Postorder(tree1$edge), tree2$edge, nTip)
+    .MASTSizeEdges(Postorder(tree1[["edge"]]), tree2[["edge"]], nTip)
   }
 }
 
